@@ -195,6 +195,7 @@ use GCExport::GCExportBase;
         $parent->{options}->{modelFile}->set_sensitive($model eq 'UseFile');
         $parent->{fieldsSelection}->set_sensitive($self->{isGeneric}->{$model})
             if $parent->{fieldsSelection};
+        $self->{wantsFieldsSelection} = $self->{isGeneric}->{$model};
     }
 
     sub preview
@@ -240,7 +241,6 @@ use GCExport::GCExportBase;
     {
         my $self = shift;
         return 1;
-        return $self->{genericAdded} || $self->{genericModels};
     }
     
     sub wantsImagesSelection
